@@ -26,7 +26,7 @@
     platform.startsWith("mac");
     isNavigatorDefined && navigator.userAgentData
         ? navigator.userAgentData.mobile
-        : userAgent.includes("mobile");
+        : userAgent.includes("mobile") || false;
     (isNavigatorDefined &&
         navigator.userAgentData &&
         ["Linux", "Android"].includes(navigator.userAgentData.platform)) ||
